"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureObservationEvent = void 0;
const AppUsageEvent_1 = require("../../domain/AppUsageEvent");
const getApplicationOfSession_1 = require("../session/getApplicationOfSession");
const captureAppUsageEvent_1 = require("./captureAppUsageEvent");
/**
 * enables programmatically capturing an observation that will be emitted as an app usage event
 *
 * usecases
 * - observe that a user has been given a particular experimental treatment
 * - observe that a user has been assigned some identifier from another analytics software
 * - etc
 *
 * note
 * - queues the requests so that even if session has not been defined yet, it will eventually succeed
 */
const captureObservationEvent = ({ type, details, }) => __awaiter(void 0, void 0, void 0, function* () {
    if (typeof window === 'undefined')
        return; // do nothing on serverside, since no installation-uuid available
    // wait for the app session to be loaded
    try {
        yield (0, getApplicationOfSession_1.waitForApplicationOfSession)();
    }
    catch (error) {
        if (!(error instanceof Error))
            throw error;
        // if the error was due to not having the app session, then just warn and exit. dont pass up the error
        if (error.message.includes('application wait attempts exceeded')) {
            console.warn('could not capture observation event, app.session was not instantiated. was the AppUsageEventProvider loaded?', { type, details });
            return;
        }
        // otherwise, pass up the error since we dont know what to do with it
        throw error;
    }
    // capture the event
    yield (0, captureAppUsageEvent_1.captureAppUsageEvent)({
        source: AppUsageEvent_1.AppUsageEventSource.OBSERVATION,
        type,
        details,
    });
});
exports.captureObservationEvent = captureObservationEvent;
//# sourceMappingURL=captureObservationEvent.js.map